@@ -1,6 +1,6 @@
 from typing import Optional
 
-from PyQt5.QtCore import QRectF
+from PyQt5.QtCore import QPointF, QRectF
 from PyQt5.QtGui import QBrush, QColor, QPainter, QPainterPath, QPen
 from PyQt5.QtWidgets import QGraphicsItem, QGraphicsPathItem
 
@@ -50,7 +50,9 @@ class QClippingPath(QGraphicsPathItem):
         clip_width: Optional[float] = None,
         scale: float = 1,
         rotation: float = 0,
-        background_brush: QBrush = None,
+        background_brush: Optional[QBrush] = None,
+        defer_geometry_calculation: bool = False,
+        transform_origin: Optional[QPointF] = None,
     ):
         """
         Args:
@@ -58,7 +60,7 @@ class QClippingPath(QGraphicsPathItem):
                 be the same as in ``QGraphicsPathItem.__init__()``
             clip_start_x: The local starting position for the path clipping region.
                 This should not adjust for scaling, as that is performed
-                automatically. Use ``None`` to render from the start.
+                automatically. Use ``0`` to render from the start.
             clip_width: The width of the path clipping region. This should not adjust
                 for scaling, as that is performed automatically. Use ``None`` to render
                 to the end
@@ -67,18 +69,25 @@ class QClippingPath(QGraphicsPathItem):
                 clipping is currently not supported.
             background_brush: If given, this will be used to paint over the path's
                 bounding rect behind the path.
+            defer_geometry_calculation: If true, this constructor will not automatically
+                calculate the path's bounding and clipping geometry. When this is set,
+                you *must* call ``update_geometry`` when the geometry is finalized.
+                This is useful when post-init modifications immediately alter the geometry,
+                preventing a redundant calculation.
         """
         super().__init__(qt_path)
-        super().setScale(scale)
         self.clip_start_x = clip_start_x / scale
         self.clip_width = None if clip_width is None else clip_width / scale
         self.setCacheMode(QGraphicsItem.CacheMode.DeviceCoordinateCache)
-        self.padding = self.pen().width() / scale
+        if transform_origin:
+            self.setTransformOriginPoint(transform_origin)
         self.setRotation(rotation)
+        super().setScale(scale)
         self.background_brush = background_brush
         self.bounding_rect = None
         self.clip_rect = None
-        self.update_geometry()
+        if not defer_geometry_calculation:
+            self.update_geometry()
 
     def boundingRect(self):
         # Seems like this is in logical space (pre-scaling)
@@ -111,13 +120,19 @@ class QClippingPath(QGraphicsPathItem):
         super().paint(painter, *args, **kwargs)
 
     def update_geometry(self):
+        """Recalculate the object's bounding and clipping rects.
+
+        This *must* be called after any changes affecting these rects, including pen
+        thickness changes.
+        """
         self.prepareGeometryChange()
         path_bounding_rect = self.path().boundingRect()
+        padding = self.pen().widthF() / 2
         self.bounding_rect = QClippingPath.calculate_bounding_rect(
             path_bounding_rect,
             self.clip_start_x,
             self.clip_width,
-            self.padding,
+            padding,
         )
         # Clip rect is used by painter, which translates by -clip_start_x,
         # so we need to cancel that out here
