@@ -1,7 +1,10 @@
+from PyQt5.QtCore import QPointF
 from PyQt5.QtGui import QBrush, QColor, QPainter, QPen
 from PyQt5.QtWidgets import QGraphicsItem, QGraphicsTextItem
 
 from neoscore.core import env
+from neoscore.core.point import ORIGIN
+from neoscore.interface.qt.converters import point_to_qt_point_f
 
 
 class QRichTextItem(QGraphicsTextItem):
@@ -12,9 +15,13 @@ class QRichTextItem(QGraphicsTextItem):
     * Enables anti-aliasing
     """
 
-    def __init__(self):
+    def __init__(
+        self,
+        transform_origin: QPointF = ORIGIN,
+    ):
         super().__init__()
         self.setCacheMode(QGraphicsItem.CacheMode.DeviceCoordinateCache)
+        self.setTransformOriginPoint(point_to_qt_point_f(transform_origin))
 
     def paint(self, painter: QPainter, *args, **kwargs):
         if env.DEBUG:
